==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_workspaces/paginator.py <==
"""
Type annotations for workspaces service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_workspaces.client import WorkSpacesClient
    from types_boto3_workspaces.paginator import (
        DescribeAccountModificationsPaginator,
        DescribeIpGroupsPaginator,
        DescribeWorkspaceBundlesPaginator,
        DescribeWorkspaceDirectoriesPaginator,
        DescribeWorkspaceImagesPaginator,
        DescribeWorkspacesConnectionStatusPaginator,
        DescribeWorkspacesPaginator,
        ListAccountLinksPaginator,
        ListAvailableManagementCidrRangesPaginator,
    )

    session = Session()
    client: WorkSpacesClient = session.client("workspaces")

    describe_account_modifications_paginator: DescribeAccountModificationsPaginator = client.get_paginator("describe_account_modifications")
    describe_ip_groups_paginator: DescribeIpGroupsPaginator = client.get_paginator("describe_ip_groups")
    describe_workspace_bundles_paginator: DescribeWorkspaceBundlesPaginator = client.get_paginator("describe_workspace_bundles")
    describe_workspace_directories_paginator: DescribeWorkspaceDirectoriesPaginator = client.get_paginator("describe_workspace_directories")
    describe_workspace_images_paginator: DescribeWorkspaceImagesPaginator = client.get_paginator("describe_workspace_images")
    describe_workspaces_connection_status_paginator: DescribeWorkspacesConnectionStatusPaginator = client.get_paginator("describe_workspaces_connection_status")
    describe_workspaces_paginator: DescribeWorkspacesPaginator = client.get_paginator("describe_workspaces")
    list_account_links_paginator: ListAccountLinksPaginator = client.get_paginator("list_account_links")
    list_available_management_cidr_ranges_paginator: ListAvailableManagementCidrRangesPaginator = client.get_paginator("list_available_management_cidr_ranges")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeAccountModificationsRequestDescribeAccountModificationsPaginateTypeDef,
    DescribeAccountModificationsResultTypeDef,
    DescribeIpGroupsRequestDescribeIpGroupsPaginateTypeDef,
    DescribeIpGroupsResultTypeDef,
    DescribeWorkspaceBundlesRequestDescribeWorkspaceBundlesPaginateTypeDef,
    DescribeWorkspaceBundlesResultTypeDef,
    DescribeWorkspaceDirectoriesRequestDescribeWorkspaceDirectoriesPaginateTypeDef,
    DescribeWorkspaceDirectoriesResultTypeDef,
    DescribeWorkspaceImagesRequestDescribeWorkspaceImagesPaginateTypeDef,
    DescribeWorkspaceImagesResultTypeDef,
    DescribeWorkspacesConnectionStatusRequestDescribeWorkspacesConnectionStatusPaginateTypeDef,
    DescribeWorkspacesConnectionStatusResultTypeDef,
    DescribeWorkspacesRequestDescribeWorkspacesPaginateTypeDef,
    DescribeWorkspacesResultTypeDef,
    ListAccountLinksRequestListAccountLinksPaginateTypeDef,
    ListAccountLinksResultTypeDef,
    ListAvailableManagementCidrRangesRequestListAvailableManagementCidrRangesPaginateTypeDef,
    ListAvailableManagementCidrRangesResultTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeAccountModificationsPaginator",
    "DescribeIpGroupsPaginator",
    "DescribeWorkspaceBundlesPaginator",
    "DescribeWorkspaceDirectoriesPaginator",
    "DescribeWorkspaceImagesPaginator",
    "DescribeWorkspacesConnectionStatusPaginator",
    "DescribeWorkspacesPaginator",
    "ListAccountLinksPaginator",
    "ListAvailableManagementCidrRangesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class DescribeAccountModificationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeAccountModifications.html#WorkSpaces.Paginator.DescribeAccountModifications)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeaccountmodificationspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            DescribeAccountModificationsRequestDescribeAccountModificationsPaginateTypeDef
        ],
    ) -> _PageIterator[DescribeAccountModificationsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeAccountModifications.html#WorkSpaces.Paginator.DescribeAccountModifications.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeaccountmodificationspaginator)
        """


class DescribeIpGroupsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeIpGroups.html#WorkSpaces.Paginator.DescribeIpGroups)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeipgroupspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeIpGroupsRequestDescribeIpGroupsPaginateTypeDef]
    ) -> _PageIterator[DescribeIpGroupsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeIpGroups.html#WorkSpaces.Paginator.DescribeIpGroups.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeipgroupspaginator)
        """


class DescribeWorkspaceBundlesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceBundles.html#WorkSpaces.Paginator.DescribeWorkspaceBundles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacebundlespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[DescribeWorkspaceBundlesRequestDescribeWorkspaceBundlesPaginateTypeDef],
    ) -> _PageIterator[DescribeWorkspaceBundlesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceBundles.html#WorkSpaces.Paginator.DescribeWorkspaceBundles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacebundlespaginator)
        """


class DescribeWorkspaceDirectoriesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceDirectories.html#WorkSpaces.Paginator.DescribeWorkspaceDirectories)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacedirectoriespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            DescribeWorkspaceDirectoriesRequestDescribeWorkspaceDirectoriesPaginateTypeDef
        ],
    ) -> _PageIterator[DescribeWorkspaceDirectoriesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceDirectories.html#WorkSpaces.Paginator.DescribeWorkspaceDirectories.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacedirectoriespaginator)
        """


class DescribeWorkspaceImagesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceImages.html#WorkSpaces.Paginator.DescribeWorkspaceImages)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspaceimagespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeWorkspaceImagesRequestDescribeWorkspaceImagesPaginateTypeDef]
    ) -> _PageIterator[DescribeWorkspaceImagesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceImages.html#WorkSpaces.Paginator.DescribeWorkspaceImages.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspaceimagespaginator)
        """


class DescribeWorkspacesConnectionStatusPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspacesConnectionStatus.html#WorkSpaces.Paginator.DescribeWorkspacesConnectionStatus)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacesconnectionstatuspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            DescribeWorkspacesConnectionStatusRequestDescribeWorkspacesConnectionStatusPaginateTypeDef
        ],
    ) -> _PageIterator[DescribeWorkspacesConnectionStatusResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspacesConnectionStatus.html#WorkSpaces.Paginator.DescribeWorkspacesConnectionStatus.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacesconnectionstatuspaginator)
        """


class DescribeWorkspacesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaces.html#WorkSpaces.Paginator.DescribeWorkspaces)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeWorkspacesRequestDescribeWorkspacesPaginateTypeDef]
    ) -> _PageIterator[DescribeWorkspacesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaces.html#WorkSpaces.Paginator.DescribeWorkspaces.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacespaginator)
        """


class ListAccountLinksPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAccountLinks.html#WorkSpaces.Paginator.ListAccountLinks)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listaccountlinkspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAccountLinksRequestListAccountLinksPaginateTypeDef]
    ) -> _PageIterator[ListAccountLinksResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAccountLinks.html#WorkSpaces.Paginator.ListAccountLinks.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listaccountlinkspaginator)
        """


class ListAvailableManagementCidrRangesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAvailableManagementCidrRanges.html#WorkSpaces.Paginator.ListAvailableManagementCidrRanges)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listavailablemanagementcidrrangespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListAvailableManagementCidrRangesRequestListAvailableManagementCidrRangesPaginateTypeDef
        ],
    ) -> _PageIterator[ListAvailableManagementCidrRangesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAvailableManagementCidrRanges.html#WorkSpaces.Paginator.ListAvailableManagementCidrRanges.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listavailablemanagementcidrrangespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_workspaces/paginator.py <==
"""
Type annotations for workspaces service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_workspaces.client import WorkSpacesClient
    from types_boto3_workspaces.paginator import (
        DescribeAccountModificationsPaginator,
        DescribeIpGroupsPaginator,
        DescribeWorkspaceBundlesPaginator,
        DescribeWorkspaceDirectoriesPaginator,
        DescribeWorkspaceImagesPaginator,
        DescribeWorkspacesConnectionStatusPaginator,
        DescribeWorkspacesPaginator,
        ListAccountLinksPaginator,
        ListAvailableManagementCidrRangesPaginator,
    )

    session = Session()
    client: WorkSpacesClient = session.client("workspaces")

    describe_account_modifications_paginator: DescribeAccountModificationsPaginator = client.get_paginator("describe_account_modifications")
    describe_ip_groups_paginator: DescribeIpGroupsPaginator = client.get_paginator("describe_ip_groups")
    describe_workspace_bundles_paginator: DescribeWorkspaceBundlesPaginator = client.get_paginator("describe_workspace_bundles")
    describe_workspace_directories_paginator: DescribeWorkspaceDirectoriesPaginator = client.get_paginator("describe_workspace_directories")
    describe_workspace_images_paginator: DescribeWorkspaceImagesPaginator = client.get_paginator("describe_workspace_images")
    describe_workspaces_connection_status_paginator: DescribeWorkspacesConnectionStatusPaginator = client.get_paginator("describe_workspaces_connection_status")
    describe_workspaces_paginator: DescribeWorkspacesPaginator = client.get_paginator("describe_workspaces")
    list_account_links_paginator: ListAccountLinksPaginator = client.get_paginator("list_account_links")
    list_available_management_cidr_ranges_paginator: ListAvailableManagementCidrRangesPaginator = client.get_paginator("list_available_management_cidr_ranges")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeAccountModificationsRequestPaginateTypeDef,
    DescribeAccountModificationsResultTypeDef,
    DescribeIpGroupsRequestPaginateTypeDef,
    DescribeIpGroupsResultTypeDef,
    DescribeWorkspaceBundlesRequestPaginateTypeDef,
    DescribeWorkspaceBundlesResultTypeDef,
    DescribeWorkspaceDirectoriesRequestPaginateTypeDef,
    DescribeWorkspaceDirectoriesResultTypeDef,
    DescribeWorkspaceImagesRequestPaginateTypeDef,
    DescribeWorkspaceImagesResultTypeDef,
    DescribeWorkspacesConnectionStatusRequestPaginateTypeDef,
    DescribeWorkspacesConnectionStatusResultTypeDef,
    DescribeWorkspacesRequestPaginateTypeDef,
    DescribeWorkspacesResultTypeDef,
    ListAccountLinksRequestPaginateTypeDef,
    ListAccountLinksResultTypeDef,
    ListAvailableManagementCidrRangesRequestPaginateTypeDef,
    ListAvailableManagementCidrRangesResultTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeAccountModificationsPaginator",
    "DescribeIpGroupsPaginator",
    "DescribeWorkspaceBundlesPaginator",
    "DescribeWorkspaceDirectoriesPaginator",
    "DescribeWorkspaceImagesPaginator",
    "DescribeWorkspacesConnectionStatusPaginator",
    "DescribeWorkspacesPaginator",
    "ListAccountLinksPaginator",
    "ListAvailableManagementCidrRangesPaginator",
)


if TYPE_CHECKING:
    _DescribeAccountModificationsPaginatorBase = Paginator[
        DescribeAccountModificationsResultTypeDef
    ]
else:
    _DescribeAccountModificationsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeAccountModificationsPaginator(_DescribeAccountModificationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeAccountModifications.html#WorkSpaces.Paginator.DescribeAccountModifications)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeaccountmodificationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAccountModificationsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeAccountModificationsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeAccountModifications.html#WorkSpaces.Paginator.DescribeAccountModifications.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeaccountmodificationspaginator)
        """


if TYPE_CHECKING:
    _DescribeIpGroupsPaginatorBase = Paginator[DescribeIpGroupsResultTypeDef]
else:
    _DescribeIpGroupsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeIpGroupsPaginator(_DescribeIpGroupsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeIpGroups.html#WorkSpaces.Paginator.DescribeIpGroups)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeipgroupspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeIpGroupsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeIpGroupsResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeIpGroups.html#WorkSpaces.Paginator.DescribeIpGroups.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeipgroupspaginator)
        """


if TYPE_CHECKING:
    _DescribeWorkspaceBundlesPaginatorBase = Paginator[DescribeWorkspaceBundlesResultTypeDef]
else:
    _DescribeWorkspaceBundlesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeWorkspaceBundlesPaginator(_DescribeWorkspaceBundlesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceBundles.html#WorkSpaces.Paginator.DescribeWorkspaceBundles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacebundlespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeWorkspaceBundlesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeWorkspaceBundlesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceBundles.html#WorkSpaces.Paginator.DescribeWorkspaceBundles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacebundlespaginator)
        """


if TYPE_CHECKING:
    _DescribeWorkspaceDirectoriesPaginatorBase = Paginator[
        DescribeWorkspaceDirectoriesResultTypeDef
    ]
else:
    _DescribeWorkspaceDirectoriesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeWorkspaceDirectoriesPaginator(_DescribeWorkspaceDirectoriesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceDirectories.html#WorkSpaces.Paginator.DescribeWorkspaceDirectories)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacedirectoriespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeWorkspaceDirectoriesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeWorkspaceDirectoriesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceDirectories.html#WorkSpaces.Paginator.DescribeWorkspaceDirectories.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacedirectoriespaginator)
        """


if TYPE_CHECKING:
    _DescribeWorkspaceImagesPaginatorBase = Paginator[DescribeWorkspaceImagesResultTypeDef]
else:
    _DescribeWorkspaceImagesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeWorkspaceImagesPaginator(_DescribeWorkspaceImagesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceImages.html#WorkSpaces.Paginator.DescribeWorkspaceImages)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspaceimagespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeWorkspaceImagesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeWorkspaceImagesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaceImages.html#WorkSpaces.Paginator.DescribeWorkspaceImages.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspaceimagespaginator)
        """


if TYPE_CHECKING:
    _DescribeWorkspacesConnectionStatusPaginatorBase = Paginator[
        DescribeWorkspacesConnectionStatusResultTypeDef
    ]
else:
    _DescribeWorkspacesConnectionStatusPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeWorkspacesConnectionStatusPaginator(_DescribeWorkspacesConnectionStatusPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspacesConnectionStatus.html#WorkSpaces.Paginator.DescribeWorkspacesConnectionStatus)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacesconnectionstatuspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeWorkspacesConnectionStatusRequestPaginateTypeDef]
    ) -> PageIterator[DescribeWorkspacesConnectionStatusResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspacesConnectionStatus.html#WorkSpaces.Paginator.DescribeWorkspacesConnectionStatus.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacesconnectionstatuspaginator)
        """


if TYPE_CHECKING:
    _DescribeWorkspacesPaginatorBase = Paginator[DescribeWorkspacesResultTypeDef]
else:
    _DescribeWorkspacesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeWorkspacesPaginator(_DescribeWorkspacesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaces.html#WorkSpaces.Paginator.DescribeWorkspaces)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeWorkspacesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeWorkspacesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/DescribeWorkspaces.html#WorkSpaces.Paginator.DescribeWorkspaces.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#describeworkspacespaginator)
        """


if TYPE_CHECKING:
    _ListAccountLinksPaginatorBase = Paginator[ListAccountLinksResultTypeDef]
else:
    _ListAccountLinksPaginatorBase = Paginator  # type: ignore[assignment]


class ListAccountLinksPaginator(_ListAccountLinksPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAccountLinks.html#WorkSpaces.Paginator.ListAccountLinks)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listaccountlinkspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAccountLinksRequestPaginateTypeDef]
    ) -> PageIterator[ListAccountLinksResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAccountLinks.html#WorkSpaces.Paginator.ListAccountLinks.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listaccountlinkspaginator)
        """


if TYPE_CHECKING:
    _ListAvailableManagementCidrRangesPaginatorBase = Paginator[
        ListAvailableManagementCidrRangesResultTypeDef
    ]
else:
    _ListAvailableManagementCidrRangesPaginatorBase = Paginator  # type: ignore[assignment]


class ListAvailableManagementCidrRangesPaginator(_ListAvailableManagementCidrRangesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAvailableManagementCidrRanges.html#WorkSpaces.Paginator.ListAvailableManagementCidrRanges)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listavailablemanagementcidrrangespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAvailableManagementCidrRangesRequestPaginateTypeDef]
    ) -> PageIterator[ListAvailableManagementCidrRangesResultTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces/paginator/ListAvailableManagementCidrRanges.html#WorkSpaces.Paginator.ListAvailableManagementCidrRanges.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_workspaces/paginators/#listavailablemanagementcidrrangespaginator)
        """
